﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;


using DigitoalNL.VELReader;
using System.IO;

namespace EnergyLogReader
{
    public partial class frmLogReader : Form
    {
        public frmLogReader()
        {
            InitializeComponent();
        }

        VELReader logReader;
        private void openLogfileToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (logReader == null) logReader = new VELReader();

            OpenFileDialog ofd = new OpenFileDialog();
            ofd.Multiselect = false;
            ofd.CheckFileExists = true;
            ofd.Filter = "Log files (*.bin)|*.bin|All files (*.*)|*.*";

            if (ofd.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                logReader.Read(ofd.FileName);

                UpdateInfo();
                UpdateData();
            }
        }

        private void scanDirectoryToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (logReader == null) logReader = new VELReader();

            FolderBrowserDialog fbd = new FolderBrowserDialog();
            fbd.ShowNewFolderButton = false;

            if (fbd.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                DirectoryInfo di = new DirectoryInfo(fbd.SelectedPath);

                foreach (FileInfo file in di.GetFiles())
                {
                    logReader.Read(file.FullName);
                }

                UpdateInfo();
                UpdateData();


            }

        }

        private void UpdateInfo() {
            lvInfo.Items.Clear();

            ListViewItem lviUID = new ListViewItem("UnitID");
            lviUID.SubItems.AddRange(new string[] { logReader.Info.UnitID.ToString(), "" });

            ListViewItem lviTPC = new ListViewItem("TotalPowerConsumed");
            lviTPC.SubItems.AddRange(new string[] { logReader.Info.TotalPowerConsumed.ToString(), "kWh" });            

            ListViewItem lviTRT = new ListViewItem("TotalRecordedTime");
            lviTRT.SubItems.AddRange(new string[] { logReader.Info.TotalRecoredTime.ToString(), "Hours" });

            ListViewItem lviTOT = new ListViewItem("TotalOnTime");
            lviTOT.SubItems.AddRange(new string[] { logReader.Info.TotalOnTime.ToString(), "Hours" });

            ListViewItem lviT1 = new ListViewItem("Tariff 1");
            lviT1.SubItems.AddRange(new string[] { logReader.Info.Tariff1.ToString(), "€/kWh" });

            ListViewItem lviT2 = new ListViewItem("Tariff 2");
            lviT2.SubItems.AddRange(new string[] { logReader.Info.Tariff2.ToString(), "€/kWh" });

            ListViewItem lviTPCT1 = new ListViewItem("TPC * Tariff 1");
            lviTPCT1.SubItems.AddRange(new string[] { logReader.Info.TotalPowerOnTariff1.ToString(), "€" });

            ListViewItem lviTPCT2 = new ListViewItem("TPC * Tariff 2");
            lviTPCT2.SubItems.AddRange(new string[] { logReader.Info.TotalPowerOnTariff2.ToString(), "€" });

            lvInfo.Items.AddRange(new ListViewItem[] { lviUID,lviTPC, lviTRT, lviTOT,lviT1,lviT2,lviTPCT1,lviTPCT2 });
        
        }
        private void UpdateData()
        {
            dgvData.DataSource = null;
            dgvData.DataSource = logReader.Log;

            /*
            int nRows = dgvData.Rows.Count;
            DateTime dtPrev = DateTime.MinValue;
            for (int i = 0; i < nRows; i++)
            {
                DateTime dtCurrent = (DateTime) dgvData.Rows[i].Cells[0].Value;

                DateTime dtDiff = dtCurrent;
                dtDiff = dtDiff.AddMinutes(-1);
                if (dtDiff > dtPrev)
                {
                    dgvData.Rows[i].DefaultCellStyle.BackColor = Color.LightGreen;
                }
                dtPrev = dtCurrent;
            }
            */
        }

        private void ExportToCSV(string filename)
        {
            if (dgvData.Rows.Count <= 0)
            {
                MessageBox.Show("Geen DATA");
                return;
            }


            StreamWriter sw = File.CreateText(filename);



            foreach (DataGridViewRow row in dgvData.Rows)
            {
                string line = "";
                line += row.Cells["LogTime"].Value.ToString() + ";";
                line += row.Cells["Voltage"].Value.ToString() + ";";
                line += row.Cells["Current"].Value.ToString() + ";";
                line += row.Cells["PowerFactor"].Value.ToString() + ";";
                line += row.Cells["VA"].Value.ToString() + ";";
                line += row.Cells["W"].Value.ToString();

                sw.WriteLine(line);
                
            }

            sw.Close();

            MessageBox.Show("File save here: \r\n"+filename);


        }

        private void exportToCSVToolStripMenuItem_Click(object sender, EventArgs e)
        {
            SaveFileDialog sfd = new SaveFileDialog();
            sfd.Title = "Save CSV as...";
            sfd.DefaultExt = ".csv";
            sfd.Filter = "CSV (*.csv)|*.csv";
            sfd.FileName = "energylog.csv";

            if (sfd.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                ExportToCSV(sfd.FileName);
            }



        }


    }
}
